summaryrefslogtreecommitdiffstats
path: root/parameter/ComponentInstance.h
diff options
context:
space:
mode:
Diffstat (limited to 'parameter/ComponentInstance.h')
-rw-r--r--parameter/ComponentInstance.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/parameter/ComponentInstance.h b/parameter/ComponentInstance.h
index 934df34..0c49a54 100644
--- a/parameter/ComponentInstance.h
+++ b/parameter/ComponentInstance.h
@@ -31,28 +31,30 @@
#include "TypeElement.h"
+#include <string>
+
class CComponentType;
class CComponentInstance : public CTypeElement
{
public:
- CComponentInstance(const string& strName);
+ CComponentInstance(const std::string& strName);
// Mapping info
- virtual bool getMappingData(const string& strKey, const string*& pStrValue) const;
+ virtual bool getMappingData(const std::string& strKey, const std::string*& pStrValue) const;
virtual bool hasMappingData() const;
/**
* Returns the mapping associated to the current TypeElement instance
*
* @return A string containing the mapping as a comma separated key value pairs
*/
- virtual string getFormattedMapping() const;
+ virtual std::string getFormattedMapping() const;
// From IXmlSink
virtual bool fromXml(const CXmlElement& xmlElement, CXmlSerializingContext& serializingContext);
// CElement
- virtual string getKind() const;
+ virtual std::string getKind() const;
private:
virtual bool childrenAreDynamic() const;
virtual CInstanceConfigurableElement* doInstantiate() const;
@@ -31,28 +31,30 @@
* Returns the mapping associated to the current TypeElement instance
*
- * @return A string containing the mapping as a comma separated key value pairs
+ * @return A std::string containing the mapping as a comma separated key value pairs
*/